//LabPlot : Point4D.h

#ifndef POINT4D_H
#define POINT4D_H

class Point4D
{
public:
	Point4D( double a=0, double b=0, double c=0, double d=0);
	void setPoint( double, double, double, double);
	double X() { return x; }
	void setX(double s) { x=s; }
	double Y() { return y; }
	void setY(double s) { y=s; }
	double Z() { return z; }
	void setZ(double s) { z=s; }
	double T() { return t; }
	void setT(double s) { t=s; }
	void setMasked(bool m=true) { masked = m; }
	bool Masked() { return masked; }
protected:
	double x,y,z,t;		
	bool masked;
};

#endif //POINT4D_H
